@@ -1,4 +1,4 @@
-# $Id: Stringprep.pm 52 2007-09-28 15:29:50Z cfaerber $
+# $Id: Stringprep.pm 66 2007-10-04 18:23:16Z cfaerber $
 
 package Unicode::Stringprep;
 
@@ -6,7 +6,7 @@ use strict;
 use utf8;
 require 5.006_000;
 
-our $VERSION = '0.99_20070927';
+our $VERSION = '0.99_20071004';
 $VERSION = eval $VERSION;
 
 require Exporter;
@@ -196,7 +196,7 @@ Unicode::Stringprep - Preparation of Internationalized Strings (S<RFC 3454>)
       @Unicode::Stringprep::Prohibited::C7, @Unicode::Stringprep::Prohibited::C8,
       @Unicode::Stringprep::Prohibited::C9 ],
     1 );
-  $output = $prepper($input)
+  $output = $prepper->($input)
 
 =head1 DESCRIPTION
 
@@ -339,6 +339,21 @@ C<Unicode::Stringprep>.
 
 =back
 
+=head1 PERL VERSION
+
+You should use perl 5.8.3 or higher.
+
+Well, these modules DO work with perl 5.6.x. However, B<you> have to make sure
+that you only pass valid UTF-8 strings to this module or you will get
+unintended results. perl 5.8.x (or higher) takes care of this by maintaining a
+UTF-8 flag for strings.
+
+With perl versions up to 5.8.2, surrogate characters (U+D800..U+DFFF) break
+string handling. If a profile tries to map these characters, they won't be
+mapped (currently no stringprep profile does this). If a profile prohibits
+these characters, this module may fail to detect them (currently, all profiles
+do that, so B<you> have to make sure that these characters are not present).
+
 =head1 AUTHOR
 
 Claus Färber <CFAERBER@cpan.org>
